@@ -1,5 +1,5 @@
 package Win32::Scsv;
-$Win32::Scsv::VERSION = '0.26';
+$Win32::Scsv::VERSION = '0.27';
 use strict;
 use warnings;
 
@@ -8,6 +8,7 @@ use Win32::OLE::Variant;
 use Carp;
 use File::Spec;
 use File::Copy;
+use Win32::File qw();
 
 use Win32::OLE::Const;
 my $Const_MSExcel = Win32::OLE::Const->Load('Microsoft Excel');
@@ -246,6 +247,23 @@ sub csv_2_xls {
         croak "tpl_abs '$tpl_abs' not found";
     }
 
+    # Force "$xls_abs" to be RW -- i.e. remove the RO flag, if any...
+    # ***************************************************************
+
+    {
+        my $aflag;
+
+        unless (Win32::File::GetAttributes($xls_abs, $aflag)) {
+            croak "Can't get attributes from '$xls_abs'";
+        }
+
+        if ($aflag & Win32::File::READONLY()) {
+            unless (Win32::File::SetAttributes($xls_abs, ($aflag & ~Win32::File::READONLY()))) {
+                croak "Can't set attribute ('RW') for '$xls_abs'";
+            }
+        }
+    }
+
     my $ole_excel = get_excel() or croak "Can't start Excel (new)";
     my $xls_book  = $ole_excel->Workbooks->Open($xls_abs) or croak "Can't Workbooks->Open xls_abs '$xls_abs'";
     my $xls_sheet = $xls_book->Worksheets($xls_snumber) or croak "Can't find Sheet '$xls_snumber' in xls_abs '$xls_abs'";
